pub struct AptRepository {
pub custom_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigAptRepositoryCustomRepository>,
pub public_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigAptRepositoryPublicRepository>,
}Expand description
Configuration for an Apt remote repository.
This type is not used in any activity, and only used as part of another schema.
Fields
custom_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigAptRepositoryCustomRepository>Customer-specified remote repository.
public_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigAptRepositoryPublicRepository>One of the publicly available Apt repositories supported by Artifact Registry.