CleanupPolicyCondition

Struct CleanupPolicyCondition 

pub struct CleanupPolicyCondition {
    pub newer_than: Option<Duration>,
    pub older_than: Option<Duration>,
    pub package_name_prefixes: Option<Vec<String>>,
    pub tag_prefixes: Option<Vec<String>>,
    pub tag_state: Option<String>,
    pub version_name_prefixes: Option<Vec<String>>,
}
CleanupPolicyCondition is a set of conditions attached to a CleanupPolicy. If multiple entries are set, all must be satisfied for the condition to be satisfied.

This type is not used in any activity, and only used as part of another schema.

Fields

newer_than: Option<Duration>

Match versions newer than a duration.

older_than: Option<Duration>

Match versions older than a duration.

package_name_prefixes: Option<Vec<String>>

Match versions by package prefix. Applied on any prefix match.

tag_prefixes: Option<Vec<String>>

Match versions by tag prefix. Applied on any prefix match.

tag_state: Option<String>

Match versions by tag status.

version_name_prefixes: Option<Vec<String>>

Match versions by version name prefix. Applied on any prefix match.