DockerImage

Struct DockerImage 

pub struct DockerImage {
    pub artifact_type: Option<String>,
    pub build_time: Option<DateTime<Utc>>,
    pub image_manifests: Option<Vec<ImageManifest>>,
    pub image_size_bytes: Option<i64>,
    pub media_type: Option<String>,
    pub name: Option<String>,
    pub tags: Option<Vec<String>>,
    pub update_time: Option<DateTime<Utc>>,
    pub upload_time: Option<DateTime<Utc>>,
    pub uri: Option<String>,
}
DockerImage represents a docker artifact. The following fields are returned as untyped metadata in the Version resource, using camelcase keys (i.e. metadata.imageSizeBytes): * imageSizeBytes * mediaType * buildTime

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

artifact_type: Option<String>

ArtifactType of this image, e.g. “application/vnd.example+type”. If the subject_digest is set and no artifact_type is given, the media_type will be considered as the artifact_type. This field is returned as the metadata.artifactType field in the Version resource.

build_time: Option<DateTime<Utc>>

The time this image was built. This field is returned as the ‘metadata.buildTime’ field in the Version resource. The build time is returned to the client as an RFC 3339 string, which can be easily used with the JavaScript Date constructor.

image_manifests: Option<Vec<ImageManifest>>

Optional. For multi-arch images (manifest lists), this field contains the list of image manifests.

image_size_bytes: Option<i64>

Calculated size of the image. This field is returned as the ‘metadata.imageSizeBytes’ field in the Version resource.

media_type: Option<String>

Media type of this image, e.g. “application/vnd.docker.distribution.manifest.v2+json”. This field is returned as the ‘metadata.mediaType’ field in the Version resource.

name: Option<String>

Required. registry_location, project_id, repository_name and image id forms a unique image name:projects//locations//repositories//dockerImages/. For example, “projects/test-project/locations/us-west4/repositories/test-repo/dockerImages/ nginx@sha256:e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf”, where “us-west4” is the registry_location, “test-project” is the project_id, “test-repo” is the repository_name and “nginx@sha256:e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf” is the image’s digest.

tags: Option<Vec<String>>

Tags attached to this image.

update_time: Option<DateTime<Utc>>

Output only. The time when the docker image was last updated.

upload_time: Option<DateTime<Utc>>

Time the image was uploaded.

uri: Option<String>

Required. URL to access the image. Example: us-west4-docker.pkg.dev/test-project/test-repo/nginx@sha256:e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf