pub struct DockerRepository {
pub custom_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigDockerRepositoryCustomRepository>,
pub public_repository: Option<String>,
}Expand description
Configuration for a Docker remote repository.
This type is not used in any activity, and only used as part of another schema.
Fields
custom_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigDockerRepositoryCustomRepository>Customer-specified remote repository.
public_repository: Option<String>One of the publicly available Docker repositories supported by Artifact Registry.