Struct GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigPythonRepositoryCustomRepository
pub struct GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigPythonRepositoryCustomRepository {
pub uri: Option<String>,
}Expand description
Customer-specified publicly available remote repository.
This type is not used in any activity, and only used as part of another schema.
Fields
uri: Option<String>An http/https uri reference to the upstream remote repository, for ex: “https://my.python.registry/”.