pub struct ListDockerImagesResponse {
pub docker_images: Option<Vec<DockerImage>>,
pub next_page_token: Option<String>,
}Expand description
The response from listing docker images.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
docker_images: Option<Vec<DockerImage>>The docker images returned.
next_page_token: Option<String>The token to retrieve the next page of artifacts, or empty if there are no more artifacts to return.