pub struct MavenRepository {
pub custom_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigMavenRepositoryCustomRepository>,
pub public_repository: Option<String>,
}Expand description
Configuration for a Maven remote repository.
This type is not used in any activity, and only used as part of another schema.
Fields
custom_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigMavenRepositoryCustomRepository>Customer-specified remote repository.
public_repository: Option<String>One of the publicly available Maven repositories supported by Artifact Registry.