pub struct NpmRepository {
pub custom_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigNpmRepositoryCustomRepository>,
pub public_repository: Option<String>,
}Expand description
Configuration for a Npm remote repository.
This type is not used in any activity, and only used as part of another schema.
Fields
custom_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigNpmRepositoryCustomRepository>Customer-specified remote repository.
public_repository: Option<String>One of the publicly available Npm repositories supported by Artifact Registry.