pub struct PythonRepository {
pub custom_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigPythonRepositoryCustomRepository>,
pub public_repository: Option<String>,
}Expand description
Configuration for a Python remote repository.
This type is not used in any activity, and only used as part of another schema.
Fields
custom_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigPythonRepositoryCustomRepository>Customer-specified remote repository.
public_repository: Option<String>One of the publicly available Python repositories supported by Artifact Registry.