pub struct UpstreamPolicy {
pub id: Option<String>,
pub priority: Option<i32>,
pub repository: Option<String>,
}Expand description
Artifact policy configuration for the repository contents.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>The user-provided ID of the upstream policy.
priority: Option<i32>Entries with a greater priority value take precedence in the pull order.
repository: Option<String>A reference to the repository resource, for example: projects/p1/locations/us-central1/repositories/repo1.