pub struct UsernamePasswordCredentials {
pub password_secret_version: Option<String>,
pub username: Option<String>,
}Expand description
Username and password credentials.
This type is not used in any activity, and only used as part of another schema.
Fields
password_secret_version: Option<String>The Secret Manager key version that holds the password to access the remote repository. Must be in the format of projects/{project}/secrets/{secret}/versions/{version}.
username: Option<String>The username to access the remote repository.