pub struct YumRepository {
pub custom_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigYumRepositoryCustomRepository>,
pub public_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigYumRepositoryPublicRepository>,
}Expand description
Configuration for a Yum remote repository.
This type is not used in any activity, and only used as part of another schema.
Fields
custom_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigYumRepositoryCustomRepository>Customer-specified remote repository.
public_repository: Option<GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigYumRepositoryPublicRepository>One of the publicly available Yum repositories supported by Artifact Registry.