pub struct ListFilesResponse {
pub files: Option<Vec<GoogleDevtoolsArtifactregistryV1File>>,
pub next_page_token: Option<String>,
}Expand description
The response from listing files.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations repositories files list projects (response)
Fields
files: Option<Vec<GoogleDevtoolsArtifactregistryV1File>>The files returned.
next_page_token: Option<String>The token to retrieve the next page of files, or empty if there are no more files to return.